PageDown Demo Page

This is the *first* editor. ------------------------------ Just plain **Markdown**, except that the input is sanitized: <marquee>I'm the ghost from the past!</marquee> and that it implements "fenced blockquotes" via a plugin: """ Do it like this: 1. Have idea. 2. ??? 3. Profit! """
This is the *second* editor. ------------------------------ It has a plugin hook registered that surrounds all words starting with the letter A with asterisks before doing the Markdown conversion. Another one gives bare links a nicer link text. User input isn't sanitized here: <marquee>I'm the ghost from the past!</marquee> http://google.com http://stackoverflow.com It also includes a help button. Finally, note that when you press Ctrl-Q or click the "Blockquote" button (without having a selection), this editor creates an example text that's different from the first editor.